summaryrefslogtreecommitdiff
path: root/emacs/gds-server.el
diff options
context:
space:
mode:
Diffstat (limited to 'emacs/gds-server.el')
-rw-r--r--emacs/gds-server.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/emacs/gds-server.el b/emacs/gds-server.el
index cca23c836..722e613db 100644
--- a/emacs/gds-server.el
+++ b/emacs/gds-server.el
@@ -26,7 +26,7 @@
:group 'scheme)
;;;; Communication with the (ossau gds-server) subprocess.
;; Subprocess output goes into the `*GDS Process*' buffer, and
;; is then read from there one form at a time. `gds-read-cursor' is
@@ -54,7 +54,7 @@ the same as the process name."
(erase-buffer)
(let* ((code (format "(begin
%s
- (use-modules (ossau gds-server))
+ (use-modules (ice-9 gds-server))
(run-server %d))"
(if gds-scheme-directory
(concat "(set! %load-path (cons "
@@ -26,7 +26,7 @@
:group 'scheme)
-;;;; Communication with the (ossau gds-server) subprocess.
+;;;; Communication with the (ice-9 gds-server) subprocess.
;; Subprocess output goes into the `*GDS Process*' buffer, and
;; is then read from there one form at a time. `gds-read-cursor' is